/*
 * Copyright (c) 2020 Giorgio Antonioli
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

@file:JvmName("StaggeredDividerDecoration")

package com.fondesa.recyclerviewdivider

import android.content.Context
import androidx.recyclerview.widget.RecyclerView

/**
 * Creates a new [StaggeredDividerBuilder] using the given [Context].
 *
 * @return a new [StaggeredDividerBuilder].
 * @see StaggeredDividerBuilder
 */
@JvmName("builder")
public fun Context.staggeredDividerBuilder(): StaggeredDividerBuilder = StaggeredDividerBuilder(context = this)

/**
 * Attaches a default divider created with [StaggeredDividerBuilder] to the given [RecyclerView].
 *
 * @see StaggeredDividerBuilder
 */
@JvmName("attachTo")
public fun RecyclerView.addStaggeredDivider() {
    context.staggeredDividerBuilder().build().addTo(this)
}
